@@ -18,8 +18,6 @@ package UI::Dialog::Backend::Nautilus;
 ###############################################################################
 use 5.006;
 use strict;
-use warnings;
-use diagnostics;
 use Carp;
 
 
@@ -29,7 +27,7 @@ use Carp;
 
 BEGIN {
     use vars qw($VERSION);
-    $VERSION = '1.02';
+    $VERSION = '1.03';
 }
 
 sub new {
